@@ -1,7 +1,6 @@
 """Hyper transformer module."""
 
 import re
-import warnings
 from copy import deepcopy
 
 import numpy as np
@@ -24,9 +23,6 @@ class HyperTransformer:
             ``transformers`` dict is built automatically from the data.
         copy (bool):
             Whether to make a copy of the input data or not. Defaults to ``True``.
-        anonymize (dict or None):
-            Dictionary specifying the names and ``faker`` categories of the categorical
-            columns that need to be anonymized. Defaults to ``None``.
         dtypes (list or None):
             List of column data types to use when building the ``transformers`` dict
             automatically. If not passed, the ``DataFrame.dtypes`` are used.
@@ -78,12 +74,10 @@ class HyperTransformer:
         'M': 'datetime',
     }
 
-    def __init__(self, transformers=None, copy=True, anonymize=None,
-                 dtypes=None, dtype_transformers=None):
+    def __init__(self, transformers=None, copy=True, dtypes=None, dtype_transformers=None):
         self.transformers = transformers
-        self._transformers = dict()
+        self._transformers = {}
         self.copy = copy
-        self.anonymize = anonymize or dict()
         self.dtypes = dtypes
         self.dtype_transformers = self._DTYPE_TRANSFORMERS.copy()
         if dtype_transformers:
@@ -115,7 +109,7 @@ class HyperTransformer:
             ValueError:
                 if a ``dtype`` is not supported by the `HyperTransformer``.
         """
-        transformers = dict()
+        transformers = {}
         if self.dtypes:
             dtypes = self.dtypes
         else:
@@ -131,7 +125,7 @@ class HyperTransformer:
                 # probably category
                 kind = 'O'
 
-            transformer_template = self.dtype_transformers[kind]
+            transformer_template = self.dtype_transformers.get(kind)
             if not transformer_template:
                 raise ValueError('Unsupported dtype: {}'.format(dtype))
 
@@ -140,12 +134,6 @@ class HyperTransformer:
 
             if not isinstance(transformer_template, type):
                 transformer = deepcopy(transformer_template)
-            elif self.anonymize and transformer_template == CategoricalTransformer:
-                warnings.warn(
-                    'Categorical anonymization is deprecated and will be removed from RDT soon.',
-                    DeprecationWarning
-                )
-                transformer = CategoricalTransformer(anonymize=self.anonymize)
             else:
                 transformer = transformer_template()
 
@@ -185,19 +173,25 @@ class HyperTransformer:
         if self.copy:
             data = data.copy()
 
+        drop_columns = []
         for column_name, transformer in self._transformers.items():
-            column = data.pop(column_name)
-            transformed = transformer.transform(column)
+            if column_name in data:
+                column = data[column_name]
+                transformed = transformer.transform(column)
 
-            shape = transformed.shape
+                shape = transformed.shape
 
-            if len(shape) == 2:
-                for index in range(shape[1]):
-                    new_column = '{}#{}'.format(column_name, index)
-                    data[new_column] = transformed[:, index]
+                if len(shape) == 2:
+                    drop_columns.append(column_name)
+                    for index in range(shape[1]):
+                        new_column = '{}#{}'.format(column_name, index)
+                        data[new_column] = transformed[:, index]
 
-            else:
-                data[column_name] = transformed
+                else:
+                    data[column_name] = transformed
+
+        if drop_columns:
+            data.drop(drop_columns, axis=1, inplace=True)
 
         return data
 
@@ -226,24 +220,11 @@ class HyperTransformer:
                 Name to match the columns.
 
         Returns:
-            numpy.ndarray:
-                values of the matching columns
-
-        Raises:
-            ValueError:
-                if no columns match.
+            list[str]:
+                Names of the matching columns.
         """
         regex = r'{}(#[0-9]+)?$'.format(re.escape(column_name))
-        columns = data.columns[data.columns.str.match(regex)]
-        if columns.empty:
-            raise ValueError('No columns match_ {}'.format(column_name))
-
-        values = [data.pop(column).values for column in columns]
-
-        if len(values) == 1:
-            return values[0]
-
-        return np.column_stack(values)
+        return data.columns[data.columns.str.match(regex)]
 
     def reverse_transform(self, data):
         """Revert the transformations back to the original values.
@@ -259,8 +240,15 @@ class HyperTransformer:
         if self.copy:
             data = data.copy()
 
+        drop_columns = []
         for column_name, transformer in self._transformers.items():
             columns = self._get_columns(data, column_name)
-            data[column_name] = transformer.reverse_transform(columns)
+            if not columns.empty:
+                columns_data = data[columns].values
+                reversed_data = transformer.reverse_transform(columns_data)
+                data[column_name] = reversed_data
+                drop_columns.extend(set(columns) - {column_name})
+
+        data.drop(drop_columns, axis=1, inplace=True)
 
         return data
