@@ -6,13 +6,14 @@ from rdt.transformers.categorical import (
     CategoricalTransformer, LabelEncodingTransformer, OneHotEncodingTransformer)
 from rdt.transformers.datetime import DatetimeTransformer
 from rdt.transformers.null import NullTransformer
-from rdt.transformers.numerical import NumericalTransformer
+from rdt.transformers.numerical import GaussianCopulaTransformer, NumericalTransformer
 
 __all__ = [
     'BaseTransformer',
     'BooleanTransformer',
     'CategoricalTransformer',
     'DatetimeTransformer',
+    'GaussianCopulaTransformer',
     'NumericalTransformer',
     'NullTransformer',
     'OneHotEncodingTransformer',
@@ -52,7 +53,7 @@ def load_transformer(transformer):
 
     transformer_kwargs = transformer.get('kwargs')
     if transformer_kwargs is None:
-        transformer_kwargs = dict()
+        transformer_kwargs = {}
 
     return transformer_class(**transformer_kwargs)
 
